@@ -30,6 +30,7 @@ from delta.tables import DeltaTable
 from pyspark.sql import SparkSession
 from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.types import StructType
+from data_product_sdk.databricks.spark import DatabricksSpark
 
 import datetime
 import json
@@ -310,6 +311,13 @@ def write_table(
                 else None
             ).start()
         else:
+            databricks_obj = DatabricksSpark()
+            databricks_obj.set_table_all_privileges(catalog_name=db_name.split(".")[0],
+                database_name=db_name.split(".")[1],
+                spark_session=spark,
+                table_modifiers=["data-platform"],
+                table_name=table_name)
+
             stream = stream.toTable(
                 tableName=f"{db_name}.{table_name}", partitionBy=partition_columns
             )
@@ -409,7 +417,7 @@ def save_database_profile_history(quality_js, profiling_s3_bucket, spark=None):
 
     if spark is None:
         spark = get_spark_session("upsert_data")
-        
+
     fields=quality_js["profilling"]["descriptiveStatistics"]["fields"]
     df = spark.createDataFrame(fields)
     df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
